{% extends "postorius/base.html" %}
{% load i18n %}
{% load bootstrap_tags %}

{% block head_title %}
{% trans 'Create list' %} - {{ block.super }}
{% endblock %}

{% block content %}

    <div class="page-header">
        <h1>{% trans 'Create a new list' %}</h1>
    </div>

    <form action="{% url 'list_new' %}" method="post" class="form-horizontal">
        {% bootstrap_form_horizontal form 2 8 'Create list' %}
        <p hidden>{% trans 'Create list' %}</p>
    </form>

{% endblock %}
