# Generated by Django 2.1.7 on 2019-03-10 07:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('postorius', '0007_auto_20180712_0536'),
    ]

    operations = [
        migrations.RenameField(
            model_name='emailtemplate',
            old_name='craeted_at',
            new_name='created_at',
        ),
    ]
